EvalError

Enum EvalError 

#[non_exhaustive]
pub enum EvalError { UnsupportedIntegralOut, MissingTableEntry, MissingBinding(VariableId), EmptySupport(VariableId), DivisionByZero, DrawOutOfRange { draw: usize, n_draws: usize, }, SupportShape { expected: usize, actual: usize, }, ProviderKind(&'static str), UnsupportedConditioning(&'static str), }
Errors from compiling or evaluating causal expressions.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnsupportedIntegralOut

Continuous IntegralOut without quadrature nodes and without discrete support.



MissingTableEntry

Provider has no entry for the requested factor / assignment.



MissingBinding(VariableId)

Required variable binding absent from the assignment.



EmptySupport(VariableId)

Provider reported empty support for a summed variable.



DivisionByZero

Division by zero while evaluating a ratio.



DrawOutOfRange

Posterior draw index out of range.

Fields

draw: usize

Requested draw.

n_draws: usize

Number of draws available.



SupportShape

Support row length does not match requested variable count.

Fields

expected: usize

Expected arity.

actual: usize

Actual arity.



ProviderKind(&'static str)

Empirical provider used where posterior draws are required (or vice versa).



UnsupportedConditioning(&'static str)

Provider cannot answer a conditional query (non-empty conditioned_on) — e.g. an independent-factor provider that only models unconditional marginals.